Learn R Programming

gps.track (version 1.0.0)

path_gps: GPS track point information extraction.

Description

Allows extracting and generating new information from track points data collected with GPS.

Usage

path_gps(
  filename = NULL,
  layer = "track_points",
  time_zone = "Etc/GMT-0",
  zone_correction = "Etc/GMT+3",
  arq_type = c("shp", "gpx")
)

Value

returns a data frame with information about time, coordinates, elevation, distance, speed, elevation difference and azimuth (always calculated in relation to the later point)

Arguments

filename

string designating the file .gpx or .shp path in geographic coordinates

layer

string that designates the layer with the trackpoint data when arq_type = "gpx", in case arq_type = "shp" layer is ignored

time_zone

string designating the gps default time zone

zone_correction

string designating the time zone for correction

arq_type

string that designates whether the file is type "shp" or "gpx", "shp" default

Examples

Run this code


path.file.ex <- base::system.file("extdata", "trajeto_teste.shp", package = "gps.track")
df.gps <-
path_gps(
  filename = path.file.ex,
  time_zone = "Etc/GMT-0",
  zone_correction = "Etc/GMT+3",
  arq_type = "shp"
)


Run the code above in your browser using DataLab